@@ -41,8 +41,6 @@ void OBSBasicSettings::InitStreamPage()
 	ui->bandwidthTestEnable->setVisible(false);
 	ui->twitchAddonDropdown->setVisible(false);
 	ui->twitchAddonLabel->setVisible(false);
-	ui->mixerAddonDropdown->setVisible(false);
-	ui->mixerAddonLabel->setVisible(false);
 
 	int vertSpacing = ui->topStreamLayout->verticalSpacing();
 
@@ -69,15 +67,14 @@ void OBSBasicSettings::InitStreamPage()
 	ui->twitchAddonDropdown->addItem(
 		QTStr("Basic.Settings.Stream.TTVAddon.Both"));
 
-	ui->mixerAddonDropdown->addItem(
-		QTStr("Basic.Settings.Stream.MixerAddon.None"));
-	ui->mixerAddonDropdown->addItem(
-		QTStr("Basic.Settings.Stream.MixerAddon.MEE"));
-
 	connect(ui->service, SIGNAL(currentIndexChanged(int)), this,
 		SLOT(UpdateServerList()));
 	connect(ui->service, SIGNAL(currentIndexChanged(int)), this,
 		SLOT(UpdateKeyLink()));
+	connect(ui->customServer, SIGNAL(textChanged(const QString &)), this,
+		SLOT(UpdateKeyLink()));
+	connect(ui->customServer, SIGNAL(editingFinished(const QString &)),
+		this, SLOT(UpdateKeyLink()));
 }
 
 void OBSBasicSettings::LoadStream1Settings()
@@ -119,9 +116,6 @@ void OBSBasicSettings::LoadStream1Settings()
 
 		idx = config_get_int(main->Config(), "Twitch", "AddonChoice");
 		ui->twitchAddonDropdown->setCurrentIndex(idx);
-
-		idx = config_get_int(main->Config(), "Mixer", "AddonChoice");
-		ui->mixerAddonDropdown->setCurrentIndex(idx);
 	}
 
 	UpdateServerList();
@@ -183,9 +177,6 @@ void OBSBasicSettings::SaveStream1Settings()
 		}
 	}
 
-	obs_data_set_bool(settings, "bwtest",
-			  ui->bandwidthTestEnable->isChecked());
-
 	if (!!auth && strcmp(auth->service(), "Twitch") == 0) {
 		bool choiceExists = config_has_user_value(
 			main->Config(), "Twitch", "AddonChoice");
@@ -198,19 +189,11 @@ void OBSBasicSettings::SaveStream1Settings()
 
 		if (choiceExists && currentChoice != newChoice)
 			forceAuthReload = true;
-	}
-	if (!!auth && strcmp(auth->service(), "Mixer") == 0) {
-		bool choiceExists = config_has_user_value(
-			main->Config(), "Mixer", "AddonChoice");
-		int currentChoice =
-			config_get_int(main->Config(), "Mixer", "AddonChoice");
-		int newChoice = ui->mixerAddonDropdown->currentIndex();
 
-		config_set_int(main->Config(), "Mixer", "AddonChoice",
-			       newChoice);
-
-		if (choiceExists && currentChoice != newChoice)
-			forceAuthReload = true;
+		obs_data_set_bool(settings, "bwtest",
+				  ui->bandwidthTestEnable->isChecked());
+	} else {
+		obs_data_set_bool(settings, "bwtest", false);
 	}
 
 	obs_data_set_string(settings, "key", QT_TO_UTF8(ui->key->text()));
@@ -231,12 +214,8 @@ void OBSBasicSettings::SaveStream1Settings()
 
 void OBSBasicSettings::UpdateKeyLink()
 {
-	if (IsCustomService()) {
-		ui->getStreamKeyButton->hide();
-		return;
-	}
-
 	QString serviceName = ui->service->currentText();
+	QString customServer = ui->customServer->text();
 	QString streamKeyLink;
 	if (serviceName == "Twitch") {
 		streamKeyLink =
@@ -246,12 +225,16 @@ void OBSBasicSettings::UpdateKeyLink()
 	} else if (serviceName.startsWith("Restream.io")) {
 		streamKeyLink =
 			"https://restream.io/settings/streaming-setup?from=OBS";
-	} else if (serviceName == "Facebook Live") {
-		streamKeyLink = "https://www.facebook.com/live/create?ref=OBS";
+	} else if (serviceName == "Facebook Live" ||
+		   (customServer.contains("fbcdn.net") && IsCustomService())) {
+		streamKeyLink =
+			"https://www.facebook.com/live/producer?ref=OBS";
 	} else if (serviceName.startsWith("Twitter")) {
 		streamKeyLink = "https://www.pscp.tv/account/producer";
 	} else if (serviceName.startsWith("YouStreamer")) {
 		streamKeyLink = "https://app.youstreamer.com/stream/";
+	} else if (serviceName == "Trovo") {
+		streamKeyLink = "https://studio.trovo.live/mychannel/stream";
 	}
 
 	if (QString(streamKeyLink).isNull()) {
@@ -287,7 +270,7 @@ void OBSBasicSettings::LoadServices(bool showAll)
 	}
 
 	if (showAll)
-		names.sort();
+		names.sort(Qt::CaseInsensitive);
 
 	for (QString &name : names)
 		ui->service->addItem(name);
@@ -332,8 +315,6 @@ void OBSBasicSettings::on_service_currentIndexChanged(int)
 	ui->bandwidthTestEnable->setVisible(false);
 	ui->twitchAddonDropdown->setVisible(false);
 	ui->twitchAddonLabel->setVisible(false);
-	ui->mixerAddonDropdown->setVisible(false);
-	ui->mixerAddonLabel->setVisible(false);
 
 #ifdef BROWSER_AVAILABLE
 	if (cef) {
@@ -491,10 +472,8 @@ void OBSBasicSettings::OnOAuthStreamKeyConnected()
 			ui->bandwidthTestEnable->setVisible(true);
 			ui->twitchAddonLabel->setVisible(true);
 			ui->twitchAddonDropdown->setVisible(true);
-		}
-		if (strcmp(a->service(), "Mixer") == 0) {
-			ui->mixerAddonLabel->setVisible(true);
-			ui->mixerAddonDropdown->setVisible(true);
+		} else {
+			ui->bandwidthTestEnable->setChecked(false);
 		}
 	}
 
@@ -555,6 +534,8 @@ void OBSBasicSettings::on_disconnectAccount_clicked()
 	OAuth::DeleteCookies(service);
 #endif
 
+	ui->bandwidthTestEnable->setChecked(false);
+
 	ui->streamKeyWidget->setVisible(true);
 	ui->streamKeyLabel->setVisible(true);
 	ui->connectAccount2->setVisible(true);
