@@ -17,6 +17,7 @@
 
 #include <inttypes.h>
 #include "obs-internal.h"
+#include "util/util_uint64.h"
 
 struct ts_info {
 	uint64_t start;
@@ -41,7 +42,7 @@ static void push_audio_tree(obs_source_t *parent, obs_source_t *source, void *p)
 
 static inline size_t convert_time_to_frames(size_t sample_rate, uint64_t t)
 {
-	return (size_t)(t * (uint64_t)sample_rate / 1000000000ULL);
+	return util_mul_div64(t, sample_rate, 1000000000ULL);
 }
 
 static inline void mix_audio(struct audio_output_data *mixes,
@@ -90,8 +91,8 @@ static void ignore_audio(obs_source_t *source, size_t channels,
 					    source->audio_input_buf[ch].size);
 
 		source->last_audio_input_buf_size = 0;
-		source->audio_ts += (uint64_t)num_floats * 1000000000ULL /
-				    (uint64_t)sample_rate;
+		source->audio_ts +=
+			util_mul_div64(num_floats, 1000000000ULL, sample_rate);
 	}
 }
 
