@@ -160,12 +160,14 @@ static void image_source_tick(void *data, float seconds)
 
 	context->update_time_elapsed += seconds;
 
-	if (context->update_time_elapsed >= 1.0f) {
-		time_t t = get_modified_timestamp(context->file);
-		context->update_time_elapsed = 0.0f;
+	if (obs_source_showing(context->source)) {
+		if (context->update_time_elapsed >= 1.0f) {
+			time_t t = get_modified_timestamp(context->file);
+			context->update_time_elapsed = 0.0f;
 
-		if (context->file_timestamp != t) {
-			image_source_load(context);
+			if (context->file_timestamp != t) {
+				image_source_load(context);
+			}
 		}
 	}
 
@@ -279,12 +281,14 @@ MODULE_EXPORT const char *obs_module_description(void)
 extern struct obs_source_info slideshow_info;
 extern struct obs_source_info color_source_info_v1;
 extern struct obs_source_info color_source_info_v2;
+extern struct obs_source_info color_source_info_v3;
 
 bool obs_module_load(void)
 {
 	obs_register_source(&image_source_info);
 	obs_register_source(&color_source_info_v1);
 	obs_register_source(&color_source_info_v2);
+	obs_register_source(&color_source_info_v3);
 	obs_register_source(&slideshow_info);
 	return true;
 }
